==> calendar-v1.7.21.zip: calendar/messages/pt/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Adicionar</strong> calendário pessoal',
    '<strong>Choose</strong> target calendar' => '<strong>Escolher</strong> calendário alvo',
    '<strong>Reminder</strong> settings' => '<strong>Definições</strong> do lembrete',
    'Add participants...' => 'Adicionar participantes...',
    'Added: {users}' => 'Adicionado: {users}',
    'Additional Information for participants' => 'Informação adicional para os participantes',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Adiciona um calendário para eventos públicos ou privados ao teu perfil e ao menu principal.',
    'Adds an event calendar to this space.' => 'Adiciona um evento a este espaço.',
    'After (occurrences)' => 'Após (ocorrências)',
    'All Day' => 'Todo o dia',
    'Allow option \'Decline\'' => 'Permitir a opção \'Recusar\'',
    'Allow option \'Undecided\'' => 'Permitir a opção \'Talvez\'',
    'Allows the user to create new calendar entries' => 'Permite à pessoa criar novas entradas de calendário',
    'Allows the user to edit/delete existing calendar entries' => 'Permite à pessoa editar/apagar entradas de calendário existentes',
    'Attending' => 'Participam',
    'Birthday' => 'Aniversário',
    'Calendar' => 'Calendário',
    'Cancel Event' => 'Cancelar Evento',
    'Cannot remove the participant!' => 'Não podes remover o participante!',
    'Create entry' => 'Criar entrada',
    'Custom reminder' => 'Lembrete personalizado',
    'Day' => 'Dia',
    'Days' => 'Dias',
    'Default reminder settings' => 'Definições padrão para o lembrete',
    'Delete all events' => 'Apagar todos os eventos',
    'Deleted' => 'Eliminada',
    'Description' => 'Descrição',
    'Do you want to install this module on your profile?' => 'Queres instalar este módulo no teu perfil?',
    'Download ICS' => 'Descarregar ICS',
    'Edit' => 'Editar',
    'Edit Event' => 'Editar Evento',
    'Edit all events' => 'Editar todos os eventos',
    'Edit this and following events' => 'Editar este evento e seguintes',
    'Edit this event' => 'Editar este evento',
    'Email' => 'Email',
    'Enable' => 'Ativar',
    'Enable Reminder' => 'Ativar Lembrete',
    'End' => 'Final',
    'End Date' => 'Data de Término',
    'End Time' => 'Hora de Término',
    'End time must be after start time!' => 'Hora do final tem que ser depois da hora de início!',
    'Event' => 'Evento',
    'Event Type' => 'Tipo de Evento',
    'Event Types' => 'Tipos de Evento',
    'Event not found!' => 'Evento não encontrado!',
    'Files' => 'Ficheiros',
    'Friday' => 'Sexta-feira',
    'Here you can configure default settings for all calendar events.' => 'Aqui podes configurar as definições padrão para todos os eventos no calendário.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Aqui podes configurar avisos globais. Estas configurações podem ser sobrescritas ao nível do espaço/perfil.',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
        <strong>Set reminder</strong> link.' => 'Aqui podes configurar as definições padrão para o lembrete deste evento. As pessoas podem sobrescrever estas definições por via do link <strong>Avisar</strong>.',
    'Hour' => 'Hora',
    'I\'m attending' => 'Vou',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Para adicionares eventos ao teu calendário, tens de ativar o módulo de calendário primeiro',
    'Interested' => 'Interessados',
    'Invalid date or time format!' => 'Formato de data ou hora inválido!',
    'Invalid day of month given' => 'Dia do mês inválido',
    'Invalid event type id selected.' => 'Selecionado id de tipo de evento inválido.',
    'Invalid frequency given' => 'Frequência inválida',
    'Invalid interval given' => 'Intervalo inválido',
    'Invalid week day selection' => 'Selecionado dia da semana inválido',
    'Invite' => 'Convidar',
    'Invited: {users}' => 'Convidados: {users}',
    'List' => 'Lista',
    'Location' => 'Local',
    'Manage entries' => 'Gerir entradas',
    'Maximum number of participants' => 'Número máximo de participantes',
    'Mode' => 'Modo',
    'Monday' => 'Segunda-feira',
    'Month' => 'Mês',
    'Monthly on day {dayOfMonth}' => 'Mensalmente no dia {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Mensalmente na {position} {dayOfWeek}',
    'Months' => 'Meses',
    'Never' => 'Nunca',
    'Next' => 'Seguinte',
    'No new participants were added.' => 'Não foram adicionados novos participantes.',
    'No new participants were invited.' => 'Não foram convidados novos participantes.',
    'No reminder' => 'Sem lembrete',
    'Notify participants about changes' => 'Notificar alterações aos particapantes',
    'On date' => 'Na data',
    'Participant removed.' => 'Participante removido.',
    'Participants' => 'Participantes',
    'Please select new participants.' => 'Por favor, seleciona novos participantes.',
    'Profile Calendar' => 'Calendário Pessoal',
    'Public' => 'Público',
    'Recurring' => 'Recorrente',
    'Reopen Event' => 'Reabrir Evento',
    'Repeat every' => 'Repetir a cada',
    'Saturday' => 'Sábado',
    'Set reminder' => 'Definir aviso',
    'Sorting' => 'Ordenação',
    'Start Date' => 'Data de Início',
    'Start Time' => 'Hora de Início',
    'Status updated.' => 'Estado atualizado.',
    'Sunday' => 'Domingo',
    'This event does not support recurrent events' => 'Este evento não permite recorrência',
    'Thursday' => 'Quinta-feira',
    'Time Zone' => 'Fuso Horário',
    'Title' => 'Título',
    'Today' => 'Hoje',
    'Tuesday' => 'Terça-feira',
    'Upcoming {type}' => 'Próximo {type}',
    'Upcoming {type}: {title}' => 'Próximo {type}: {title}',
    'Use default reminder' => 'Usar lembrete padrão',
    'User birthdays' => 'Aniversários dos membros',
    'Wednesday' => 'Quarta-feira',
    'Week' => 'Semana',
    'Weeks' => 'Semanas',
    'Year' => 'Ano',
    'Years' => 'Anos',
    'You cannot invite participants!' => 'Não podes convidar participantes!',
    'You don\'t have permission to delete this event!' => 'Não tens permissão para apagar este evento!',
    'You have an <strong>{type}</strong> coming up' => 'Tens um <strong>{type}</strong> em breve',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Tens um <strong>{type}</strong> em breve: {title}',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'As tuas definições de lembrete para o evento: <strong>\'{title}\'</strong>',
    'canceled' => 'cancelado',
    'disabled' => 'Desativado',
    'first' => 'primeira',
    'forth' => 'quarta',
    'last' => 'última',
    'on weekdays' => 'em dias úteis',
    'second' => 'segunda',
    'third' => 'terceira',
    '{displayName} Birthday' => 'Aniversário de {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} adicionou-te ao evento "{contentTitle}" no espaço {spaceName} com início às {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} adicionou-te ao evento "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} convidou-te para o evento "{contentTitle}" no espaço {spaceName} que terá início às {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} convidou-te para o evento "{contentTitle}".',
    'Add all Space members with status {status}' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Display events within the next X days' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Export as {type}' => '',
    'Filter by types' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Minute' => '',
    'Participation Status' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Status cannot be updated.' => '',
    'The event has already ended.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{name} Calendar' => '',
];

==> calendar-v1.8.3.zip: calendar/messages/pt/base.php <==
<?php

return [
    '<strong>Add</strong> profile calendar' => '<strong>Adicionar</strong> calendário pessoal',
    '<strong>Choose</strong> target calendar' => '<strong>Escolher</strong> calendário alvo',
    '<strong>Reminder</strong> settings' => '<strong>Definições</strong> do lembrete',
    'Add participants...' => 'Adicionar participantes...',
    'Added: {users}' => 'Adicionado: {users}',
    'Additional Information for participants' => 'Informação adicional para os participantes',
    'Adds a calendar for private or public events to your profile and main menu.' => 'Adiciona um calendário para eventos públicos ou privados ao teu perfil e ao menu principal.',
    'Adds an event calendar to this space.' => 'Adiciona um evento a este espaço.',
    'After (occurrences)' => 'Após (ocorrências)',
    'All Day' => 'Todo o dia',
    'Allow option \'Decline\'' => 'Permitir a opção \'Recusar\'',
    'Allow option \'Undecided\'' => 'Permitir a opção \'Talvez\'',
    'Allows the user to create new calendar entries' => 'Permite à pessoa criar novas entradas de calendário',
    'Allows the user to edit/delete existing calendar entries' => 'Permite à pessoa editar/apagar entradas de calendário existentes',
    'Attending' => 'Participam',
    'Birthday' => 'Aniversário',
    'Calendar' => 'Calendário',
    'Cancel Event' => 'Cancelar Evento',
    'Cannot remove the participant!' => 'Não podes remover o participante!',
    'Create entry' => 'Criar entrada',
    'Custom reminder' => 'Lembrete personalizado',
    'Day' => 'Dia',
    'Days' => 'Dias',
    'Default reminder settings' => 'Definições padrão para o lembrete',
    'Delete all events' => 'Apagar todos os eventos',
    'Deleted' => 'Eliminada',
    'Description' => 'Descrição',
    'Do you want to install this module on your profile?' => 'Queres instalar este módulo no teu perfil?',
    'Download ICS' => 'Descarregar ICS',
    'Edit' => 'Editar',
    'Edit Event' => 'Editar Evento',
    'Edit all events' => 'Editar todos os eventos',
    'Edit this and following events' => 'Editar este evento e seguintes',
    'Edit this event' => 'Editar este evento',
    'Email' => 'Email',
    'Enable' => 'Ativar',
    'Enable Reminder' => 'Ativar Lembrete',
    'End' => 'Final',
    'End Date' => 'Data de Término',
    'End Time' => 'Hora de Término',
    'End time must be after start time!' => 'Hora do final tem que ser depois da hora de início!',
    'Event' => 'Evento',
    'Event Type' => 'Tipo de Evento',
    'Event Types' => 'Tipos de Evento',
    'Event not found!' => 'Evento não encontrado!',
    'Files' => 'Ficheiros',
    'Friday' => 'Sexta-feira',
    'Here you can configure default settings for all calendar events.' => 'Aqui podes configurar as definições padrão para todos os eventos no calendário.',
    'Here you can configure global default reminders. These settings can be overwritten on space/profile level.' => 'Aqui podes configurar avisos globais. Estas configurações podem ser sobrescritas ao nível do espaço/perfil.',
    'Hour' => 'Hora',
    'I\'m attending' => 'Vou',
    'ID' => 'ID',
    'In order to add events to your profile, you have to enable the calendar module first.' => 'Para adicionares eventos ao teu calendário, tens de ativar o módulo de calendário primeiro',
    'Interested' => 'Interessados',
    'Invalid date or time format!' => 'Formato de data ou hora inválido!',
    'Invalid day of month given' => 'Dia do mês inválido',
    'Invalid event type id selected.' => 'Selecionado id de tipo de evento inválido.',
    'Invalid frequency given' => 'Frequência inválida',
    'Invalid interval given' => 'Intervalo inválido',
    'Invalid week day selection' => 'Selecionado dia da semana inválido',
    'Invite' => 'Convidar',
    'Invited: {users}' => 'Convidados: {users}',
    'List' => 'Lista',
    'Location' => 'Local',
    'Manage entries' => 'Gerir entradas',
    'Maximum number of participants' => 'Número máximo de participantes',
    'Mode' => 'Modo',
    'Monday' => 'Segunda-feira',
    'Month' => 'Mês',
    'Monthly on day {dayOfMonth}' => 'Mensalmente no dia {dayOfMonth}',
    'Monthly on the {position} {dayOfWeek}' => 'Mensalmente na {position} {dayOfWeek}',
    'Months' => 'Meses',
    'Never' => 'Nunca',
    'Next' => 'Seguinte',
    'No new participants were added.' => 'Não foram adicionados novos participantes.',
    'No new participants were invited.' => 'Não foram convidados novos participantes.',
    'No reminder' => 'Sem lembrete',
    'Notify participants about changes' => 'Notificar alterações aos particapantes',
    'On date' => 'Na data',
    'Participant removed.' => 'Participante removido.',
    'Participants' => 'Participantes',
    'Please select new participants.' => 'Por favor, seleciona novos participantes.',
    'Profile Calendar' => 'Calendário Pessoal',
    'Public' => 'Público',
    'Recurring' => 'Recorrente',
    'Reopen Event' => 'Reabrir Evento',
    'Repeat every' => 'Repetir a cada',
    'Saturday' => 'Sábado',
    'Set reminder' => 'Definir aviso',
    'Sorting' => 'Ordenação',
    'Start Date' => 'Data de Início',
    'Start Time' => 'Hora de Início',
    'Status updated.' => 'Estado atualizado.',
    'Sunday' => 'Domingo',
    'This event does not support recurrent events' => 'Este evento não permite recorrência',
    'Thursday' => 'Quinta-feira',
    'Time Zone' => 'Fuso Horário',
    'Title' => 'Título',
    'Today' => 'Hoje',
    'Tuesday' => 'Terça-feira',
    'Upcoming {type}' => 'Próximo {type}',
    'Upcoming {type}: {title}' => 'Próximo {type}: {title}',
    'Use default reminder' => 'Usar lembrete padrão',
    'User birthdays' => 'Aniversários dos membros',
    'Wednesday' => 'Quarta-feira',
    'Week' => 'Semana',
    'Weeks' => 'Semanas',
    'Year' => 'Ano',
    'Years' => 'Anos',
    'You cannot invite participants!' => 'Não podes convidar participantes!',
    'You don\'t have permission to delete this event!' => 'Não tens permissão para apagar este evento!',
    'You have an <strong>{type}</strong> coming up' => 'Tens um <strong>{type}</strong> em breve',
    'You have an <strong>{type}</strong> coming up: {title}' => 'Tens um <strong>{type}</strong> em breve: {title}',
    'Your reminder settings for event: <strong>\'{title}\'</strong>' => 'As tuas definições de lembrete para o evento: <strong>\'{title}\'</strong>',
    'canceled' => 'cancelado',
    'disabled' => 'Desativado',
    'first' => 'primeira',
    'forth' => 'quarta',
    'last' => 'última',
    'on weekdays' => 'em dias úteis',
    'second' => 'segunda',
    'third' => 'terceira',
    '{displayName} Birthday' => 'Aniversário de {displayName}',
    '{displayName} added you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} adicionou-te ao evento "{contentTitle}" no espaço {spaceName} com início às {time}.',
    '{displayName} added you to the event "{contentTitle}".' => '{displayName} adicionou-te ao evento "{contentTitle}".',
    '{displayName} invited you to the event "{contentTitle}" in the space {spaceName}, starting at {time}.' => '{displayName} convidou-te para o evento "{contentTitle}" no espaço {spaceName} que terá início às {time}.',
    '{displayName} invited you to the event "{contentTitle}".' => '{displayName} convidou-te para o evento "{contentTitle}".',
    'Add all Space members with status {status}' => '',
    'Before a target calendar can be selected, the module must be activated in at least one Space.' => '',
    'CalDAV' => '',
    'Calendar event' => '',
    'Calendar event content ID' => '',
    'Calendar events' => '',
    'Display events within the next X days' => '',
    'Event could not be deleted!' => '',
    'Event has been be deleted!' => '',
    'Export as {type}' => '',
    'Filter' => '',
    'Filter by types' => '',
    'From Newest to Oldest' => '',
    'From Oldest to Newest' => '',
    'Here you can configure the default reminder settings for this event. Users are able to overwrite these settings by means of the
    <strong>Set reminder</strong> link.' => '',
    'Include Organizer and Participant Info in Exports' => '',
    'JWT Key' => '',
    'JWT Token Expiration' => '',
    'Leave empty to list all events. Enter 0 to display only today\'s events.' => '',
    'Minute' => '',
    'Participation Status' => '',
    'Private events are only visible to you and, if the friendship system is activated, to your friends.' => '',
    'Select calendar...' => '',
    'Select space...' => '',
    'Show past events' => '',
    'Status cannot be updated.' => '',
    'The event has already ended.' => '',
    'Used for secure iCal feed URL generation and CalDAV authentication. Changing this key will revoke all existing iCal URLs and CalDAV logins. If empty, a random key is generated automatically.' => '',
    'When enabled, calendar exports (ics, iCal, CalDAV) will include the organizer\'s and participant\'s names and email addresses. Disable to exclude this information for increased privacy.' => '',
    'You have been registered for the event "{contentTitle}" in {spaceName}, starting at {time}' => '',
    'You have been registered for the event "{contentTitle}", starting at {time}.' => '',
    'You have been registered for the event "{contentTitle}".' => '',
    'global' => '',
    'iCal' => '',
    'in seconds. 0 for no JWT token expiration.' => '',
    '{name} Calendar' => '',
];
